==> FitGallery-0.85.tar.gz: FitGallery-0.85/www/common_html.php <==
<?php

# FitGallery 0.85
# (C) Omar Lpez 'pollo' (pollo.es.pollo@gmail.com), Enrique D. Bosch 'presi' (presidev@confluencia.net)
# http://fitgallery.presi.org
#
# common html functions

#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#
#    http://www.gnu.org/licenses/gpl.html


function html_header($style,$texto_titulo,$version)
{

echo '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN"
      "http://www.w3.org/TR/html4/strict.dtd">
';
echo "<!-- FitGallery $version copyleft GPL by Pollo and Presi http://fitgallery.presi.org -->\n";
echo '<html>
<head>
<style type="text/css">
<!--';
include "styles/$style";
echo '-->
</style>
<title>'.$texto_titulo.'</title>
</head>
<body>
';

}


function html_bottom($powered, $text_powered, $version)
{

echo '<p class="clear">
<a href="http://validator.w3.org/check/referer">
<img class="w3c" src="valid-html401.png" alt="Valid HTML 4.01!" height="31" width="88">
</a>
</p>
';

if ($powered) echo "<p class=\"normal\">$text_powered<a href=\"http://fitgallery.presi.org\">FitGallery $version</a></p>";

echo "\n</body>\n</html>\n";

}


function html_sep()
{
echo '
<p class="clear">
<br>
</p>
';
}

?>

==> FitGallery-0.90.tar.gz: FitGallery-0.90/www/common_html.php <==
<?php

# FitGallery 0.90
# (C) Copyright  Omar Lpez 'pollo', Enrique D. Bosch 'presi'
# http://fitgallery.presi.org
#
# common html functions

#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#    http://www.gnu.org/licenses/gpl.html


function html_header($style,$texto_titulo,$version,$charset,$lang)
{

echo '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN"
      "http://www.w3.org/TR/html4/strict.dtd">
';
echo "<!-- FitGallery $version copyleft GPL by Pollo and Presi http://fitgallery.presi.org -->\n";
echo '<html lang="'.$lang.'">
<head>
<meta http-equiv="Content-Type" content="text/html;charset='.$charset.'">
<meta name="generator" content="FitGallery http://fitgallery.presi.org">
<style type="text/css">
<!--';
include "styles/$style";
echo '-->
</style>
<title>'.$texto_titulo.'</title>
</head>
<body>
';

}


function html_bottom($powered, $text_powered, $version, $w3logo)
{


if ($w3logo) echo '<p class="clear">
<a href="http://validator.w3.org/check/referer">
<img class="w3c" src="valid-html401.png" alt="Valid HTML 4.01!" height="31" width="88">
</a>
</p>
';

if ($powered) echo "<p class=\"normal\">$text_powered<a href=\"http://fitgallery.presi.org\">FitGallery $version</a></p>";

echo "\n</body>\n</html>\n";

}


function html_sep()
{
echo '
<p class="clear">
<br>
</p>
';
}

?>
